
#ifndef _C10_ev491_
#define _C10_ev491_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1127_10104(EIF_REFERENCE);
extern void EIF_Minit491(void);
extern EIF_REFERENCE F1190_11269(EIF_REFERENCE);
extern long O8104[];
extern long O7125[];

#ifdef __cplusplus
}
#endif

#endif
